==> pyspark_easy-0.5.tar.gz: pyspark_easy-0.5/setup.py <==
from distutils.core import setup
setup(
  name = 'pyspark_easy',         # How you named your package folder (MyLib)
  packages = ['pyspark_easy'],   # Chose the same as "name"
  version = '0.5',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Makes pyspark dataframe exploration easy',   # Give a short description about your library
  author = 'Nareshkumar Jayavelu',                   # Type in your name
  author_email = 'nareshkumarj90@gmail.com',      # Type in your E-Mail
  url = 'https://https://github.com/naresh-datanut/pyspark_easy',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',    # I explain this later on
  keywords = ['pyspark', 'dataframe', 'summary','explore','EDA'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'pyspark',
          'texttable',
          'pyspark_easy'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> pyspark_easy-0.9.tar.gz: pyspark_easy-0.9/setup.py <==
from distutils.core import setup
setup(
  name = 'pyspark_easy',         # How you named your package folder (MyLib)
  packages = ['pyspark_easy'],   # Chose the same as "name"
  version = '0.9',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Makes pyspark dataframe exploration easy',   # Give a short description about your library
  author = 'Nareshkumar Jayavelu',                   # Type in your name
  author_email = 'nareshkumarj90@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/naresh-datanut/pyspark-easy',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/naresh-datanut/pyspark-easy/archive/0.9.tar.gz',    # I explain this later on
  keywords = ['pyspark', 'dataframe', 'summary','explore','EDA'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'pyspark',
          'texttable'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
